# Fitness Tracker
Fitness Tracker is a desktop application used to track lifestyle and fitness progress.

# Features
## Calculators
### 1 Rep Max Calculator
The one rep max calculator is a calculator that uses the Brzycki formula to estimate your one rep max based on 2 parameters: weight and number of repetitions. This tool also shows the recommended progression to the estimated one rep max, aswell as recommended rest times.
Learn more about the Brzycki formula [here](https://www.vcalc.com/wiki/Caroline4/Brzycki).

### Strength Estmitator
The strength estimator estimates your strength level for one of the 3 main lifts in powerlifting (Horizontal Bench Press, Back Squat, Deadlift). This works by comparing your one rep max result in a lift with worldwide strength standards for a certain age group, gender and bodyweight class. The worldwide standard is presented in a table.

### Body Fat Calculator
This calculator calculates your body fat based on your measurements such as height, weight, waist circumference, etc. The results this calculator gives are your body fat using the U.S. Navy Method and the BMI Method, body fat category, body fat mass, lean body mass, ideal body fat for a given age (Jackson-Pollock standard) and the body fat required to lose to reach ideal body fat.


## Notes
### Big Lifts
This panel allows you to keep notes of 4 preferred powerlifting lifts. It allows you to keep notes of your achieved one rep maxes as well as lifts you've done for repetitions. Your one rep max history is presented on a graph so you can keep track of your progress. You can view your lift history and change your preferred lifts. There are 4 categories of lifts you can change: Horizontal Press, Floor Pull, Squat and Vertical Press.

### Weight Loss Notes
Here you can keep notes of your weight loss journey. You can set your desired weight and change your current weight. Your current weight changes will be stored so you can keep track of your weight loss on a calendar or a graph.

### Nutrition
This feature consists of 2 panels: Notes and Food Database.

The notes panel allows you to calculate your recommended calorie intake whether you want to lose weight, maintain or gain weight. It also allows you to plan and create optimal meals to cover your calorie and other nutrient needs. The nutrients and calories for the current day are calculated and shown. You can use a filter to filter out nutrients you need or do not need. It also calculates your monthly nutrient intake (days that have no data are ignored). 

The food database allows you to search through food and recipes. You can click on a certain food to check its caloric value and nutrients.

### Workout Notes
This is a planner to create your own workout plans. Search through our database for exercises for a certain muscle group.

https://www.spoonacular.com/

https://www.wger.de/api/v2/
